@@ -30,53 +30,53 @@ extern "C" {
     pub fn _acb_vec_clear(v: acb_ptr, n: mp_limb_signed_t);
     pub fn acb_real_ptr(z: *mut acb_struct) -> arb_ptr;
     pub fn acb_imag_ptr(z: *mut acb_struct) -> arb_ptr;
-    pub fn acb_get_real(re: *mut arb_struct, z: *mut acb_struct);
-    pub fn acb_get_imag(im: *mut arb_struct, z: *mut acb_struct);
-    pub fn acb_get_mid(res: *mut acb_struct, x: *mut acb_struct);
-    pub fn acb_is_zero(z: *mut acb_struct) -> c_int;
-    pub fn acb_is_one(z: *mut acb_struct) -> c_int;
-    pub fn acb_is_exact(z: *mut acb_struct) -> c_int;
-    pub fn acb_is_int(z: *mut acb_struct) -> c_int;
-    pub fn acb_is_int_2exp_si(z: *mut acb_struct, e: mp_limb_signed_t) -> c_int;
+    pub fn acb_get_real(re: *mut arb_struct, z: *const acb_struct);
+    pub fn acb_get_imag(im: *mut arb_struct, z: *const acb_struct);
+    pub fn acb_get_mid(res: *mut acb_struct, x: *const acb_struct);
+    pub fn acb_is_zero(z: *const acb_struct) -> c_int;
+    pub fn acb_is_one(z: *const acb_struct) -> c_int;
+    pub fn acb_is_exact(z: *const acb_struct) -> c_int;
+    pub fn acb_is_int(z: *const acb_struct) -> c_int;
+    pub fn acb_is_int_2exp_si(z: *const acb_struct, e: mp_limb_signed_t) -> c_int;
     pub fn acb_zero(z: *mut acb_struct);
     pub fn acb_one(z: *mut acb_struct);
     pub fn acb_onei(z: *mut acb_struct);
-    pub fn acb_set(z: *mut acb_struct, x: *mut acb_struct);
-    pub fn acb_set_round(z: *mut acb_struct, x: *mut acb_struct, prec: mp_limb_signed_t);
-    pub fn acb_neg_round(z: *mut acb_struct, x: *mut acb_struct, prec: mp_limb_signed_t);
+    pub fn acb_set(z: *mut acb_struct, x: *const acb_struct);
+    pub fn acb_set_round(z: *mut acb_struct, x: *const acb_struct, prec: mp_limb_signed_t);
+    pub fn acb_neg_round(z: *mut acb_struct, x: *const acb_struct, prec: mp_limb_signed_t);
     pub fn acb_swap(z: *mut acb_struct, x: *mut acb_struct);
-    pub fn acb_equal(x: *mut acb_struct, y: *mut acb_struct) -> c_int;
-    pub fn acb_equal_si(x: *mut acb_struct, y: mp_limb_signed_t) -> c_int;
-    pub fn acb_eq(x: *mut acb_struct, y: *mut acb_struct) -> c_int;
-    pub fn acb_ne(x: *mut acb_struct, y: *mut acb_struct) -> c_int;
-    pub fn acb_overlaps(x: *mut acb_struct, y: *mut acb_struct) -> c_int;
-    pub fn acb_contains_zero(x: *mut acb_struct) -> c_int;
-    pub fn acb_contains_fmpq(x: *mut acb_struct, y: *mut fmpq) -> c_int;
-    pub fn acb_contains_fmpz(x: *mut acb_struct, y: *mut fmpz) -> c_int;
-    pub fn acb_contains(x: *mut acb_struct, y: *mut acb_struct) -> c_int;
-    pub fn acb_contains_interior(x: *mut acb_struct, y: *mut acb_struct) -> c_int;
+    pub fn acb_equal(x: *const acb_struct, y: *const acb_struct) -> c_int;
+    pub fn acb_equal_si(x: *const acb_struct, y: mp_limb_signed_t) -> c_int;
+    pub fn acb_eq(x: *const acb_struct, y: *const acb_struct) -> c_int;
+    pub fn acb_ne(x: *const acb_struct, y: *const acb_struct) -> c_int;
+    pub fn acb_overlaps(x: *const acb_struct, y: *const acb_struct) -> c_int;
+    pub fn acb_contains_zero(x: *const acb_struct) -> c_int;
+    pub fn acb_contains_fmpq(x: *const acb_struct, y: *const fmpq) -> c_int;
+    pub fn acb_contains_fmpz(x: *const acb_struct, y: *const fmpz) -> c_int;
+    pub fn acb_contains(x: *const acb_struct, y: *const acb_struct) -> c_int;
+    pub fn acb_contains_interior(x: *const acb_struct, y: *const acb_struct) -> c_int;
     pub fn acb_set_ui(z: *mut acb_struct, c: mp_limb_t);
     pub fn acb_set_d(z: *mut acb_struct, c: f64);
     pub fn acb_set_si(z: *mut acb_struct, c: mp_limb_signed_t);
     pub fn acb_set_si_si(z: *mut acb_struct, x: mp_limb_signed_t, y: mp_limb_signed_t);
     pub fn acb_set_d_d(z: *mut acb_struct, x: f64, y: f64);
-    pub fn acb_set_fmpz(z: *mut acb_struct, c: *mut fmpz);
-    pub fn acb_set_fmpz_fmpz(z: *mut acb_struct, x: *mut fmpz, y: *mut fmpz);
-    pub fn acb_set_round_fmpz(z: *mut acb_struct, y: *mut fmpz, prec: mp_limb_signed_t);
-    pub fn acb_contains_int(x: *mut acb_struct) -> c_int;
-    pub fn acb_get_unique_fmpz(z: *mut fmpz, x: *mut acb_struct) -> c_int;
-    pub fn acb_set_fmpq(z: *mut acb_struct, c: *mut fmpq, prec: mp_limb_signed_t);
-    pub fn acb_set_arb(z: *mut acb_struct, c: *mut arb_struct);
-    pub fn acb_set_arb_arb(z: *mut acb_struct, x: *mut arb_struct, y: *mut arb_struct);
-    pub fn acb_set_round_arb(z: *mut acb_struct, x: *mut arb_struct, prec: mp_limb_signed_t);
-    pub fn acb_trim(z: *mut acb_struct, x: *mut acb_struct);
-    pub fn acb_add_error_arf(x: *mut acb_struct, err: *mut arf_struct);
-    pub fn acb_add_error_mag(x: *mut acb_struct, err: *mut mag_struct);
-    pub fn acb_get_mag(z: *mut mag_struct, x: *mut acb_struct);
-    pub fn acb_get_mag_lower(z: *mut mag_struct, x: *mut acb_struct);
-    pub fn acb_get_abs_ubound_arf(u: *mut arf_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-    pub fn acb_get_abs_lbound_arf(u: *mut arf_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-    pub fn acb_get_rad_ubound_arf(u: *mut arf_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
+    pub fn acb_set_fmpz(z: *mut acb_struct, c: *const fmpz);
+    pub fn acb_set_fmpz_fmpz(z: *mut acb_struct, x: *const fmpz, y: *const fmpz);
+    pub fn acb_set_round_fmpz(z: *mut acb_struct, y: *const fmpz, prec: mp_limb_signed_t);
+    pub fn acb_contains_int(x: *const acb_struct) -> c_int;
+    pub fn acb_get_unique_fmpz(z: *mut fmpz, x: *const acb_struct) -> c_int;
+    pub fn acb_set_fmpq(z: *mut acb_struct, c: *const fmpq, prec: mp_limb_signed_t);
+    pub fn acb_set_arb(z: *mut acb_struct, c: *const arb_struct);
+    pub fn acb_set_arb_arb(z: *mut acb_struct, x: *const arb_struct, y: *const arb_struct);
+    pub fn acb_set_round_arb(z: *mut acb_struct, x: *const arb_struct, prec: mp_limb_signed_t);
+    pub fn acb_trim(z: *mut acb_struct, x: *const acb_struct);
+    pub fn acb_add_error_arf(x: *mut acb_struct, err: *const arf_struct);
+    pub fn acb_add_error_mag(x: *mut acb_struct, err: *const mag_struct);
+    pub fn acb_get_mag(z: *mut mag_struct, x: *const acb_struct);
+    pub fn acb_get_mag_lower(z: *mut mag_struct, x: *const acb_struct);
+    pub fn acb_get_abs_ubound_arf(u: *mut arf_struct, z: *const acb_struct, prec: mp_limb_signed_t);
+    pub fn acb_get_abs_lbound_arf(u: *mut arf_struct, z: *const acb_struct, prec: mp_limb_signed_t);
+    pub fn acb_get_rad_ubound_arf(u: *mut arf_struct, z: *const acb_struct, prec: mp_limb_signed_t);
     pub fn acb_union(
         res: *mut acb_struct,
         x: *mut acb_struct,
