@@ -1,14 +1,73 @@
 #![allow(non_camel_case_types)]
+#![allow(non_snake_case)]
 
-//! *See the [ARB documentation](https://arblib.org/).
+//! *See the [Arb documentation](https://arblib.org/).
 
 use flint_sys::deps::*;
-use flint_sys::flint::*;
 use flint_sys::fmpz::fmpz;
-use flint_sys::fmpq::fmpq;
-use crate::fmpr::fmpr_struct;
-use libc::{c_char, c_int, FILE};
+use crate::mag::mag_struct;
+use crate::arf::arf_struct;
+use crate::arb::{arb_struct, arb_ptr, arb_srcptr};
+use crate::acb::{acb_struct, acb_t, acb_ptr, acb_srcptr};
+use crate::acb_poly::acb_poly_struct;
+use crate::dirichlet::{dirichlet_group_struct, dirichlet_char_struct};
 
+#[repr(C)]
+#[derive(Copy, Clone)]
+pub struct acb_dirichlet_hurwitz_precomp_struct {
+    pub s: acb_struct,
+    pub err: mag_struct,
+    pub coeffs: acb_ptr,
+    pub deflate: ::std::os::raw::c_int,
+    pub A: mp_limb_signed_t,
+    pub N: mp_limb_signed_t,
+    pub K: mp_limb_signed_t,
+}
+
+pub type acb_dirichlet_hurwitz_precomp_t = [acb_dirichlet_hurwitz_precomp_struct; 1usize];
+
+#[repr(C)]
+#[derive(Copy, Clone)]
+pub struct acb_dirichlet_roots_struct {
+    pub order: mp_limb_t,
+    pub reduced_order: mp_limb_t,
+    pub z: acb_t,
+    pub size: mp_limb_signed_t,
+    pub depth: mp_limb_signed_t,
+    pub Z: *mut acb_ptr,
+    pub use_pow: ::std::os::raw::c_int,
+}
+
+pub type acb_dirichlet_roots_t = [acb_dirichlet_roots_struct; 1usize];
+
+#[repr(C)]
+#[derive(Copy, Clone)]
+pub struct acb_dirichlet_platt_c_precomp_struct {
+    pub len: mp_limb_signed_t,
+    pub p: arb_ptr,
+    pub Xa: arb_struct,
+    pub Xb: arb_struct,
+}
+
+pub type acb_dirichlet_platt_c_precomp_t = [acb_dirichlet_platt_c_precomp_struct; 1usize];
+
+#[repr(C)]
+#[derive(Copy, Clone)]
+pub struct acb_dirichlet_platt_i_precomp_struct {
+    pub c1: arb_struct,
+    pub c2: arb_struct,
+}
+
+pub type acb_dirichlet_platt_i_precomp_t = [acb_dirichlet_platt_i_precomp_struct; 1usize];
+
+#[repr(C)]
+#[derive(Copy, Clone)]
+pub struct acb_dirichlet_platt_ws_precomp_struct {
+    pub pre_c: acb_dirichlet_platt_c_precomp_struct,
+    pub pre_i: acb_dirichlet_platt_i_precomp_struct,
+}
+
+pub type acb_dirichlet_platt_ws_precomp_t = [acb_dirichlet_platt_ws_precomp_struct; 1usize];
 
 extern "C" {
     pub fn acb_dirichlet_powsum_term(
@@ -22,8 +81,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_powsum_sieved(
         z: acb_ptr,
         s: *mut acb_struct,
@@ -31,8 +88,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_powsum_smooth(
         z: acb_ptr,
         s: *mut acb_struct,
@@ -40,68 +95,48 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_zeta_bound(res: *mut mag_struct, s: *mut acb_struct);
-}
-extern "C" {
     pub fn acb_dirichlet_zeta_deriv_bound(
         der1: *mut mag_struct,
         der2: *mut mag_struct,
         s: *mut acb_struct,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_zeta_rs_f_coeffs(
         c: acb_ptr,
         p: *mut arb_struct,
         N: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_zeta_rs_d_coeffs(
         d: arb_ptr,
         sigma: *mut arb_struct,
         k: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_zeta_rs_bound(
         err: *mut mag_struct,
         s: *mut acb_struct,
         K: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_zeta_rs_r(
         res: *mut acb_struct,
         s: *mut acb_struct,
         K: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_zeta_rs(
         res: *mut acb_struct,
         s: *mut acb_struct,
         K: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_zeta(res: *mut acb_struct, s: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn acb_dirichlet_zeta_jet_rs(
         res: acb_ptr,
         s: *mut acb_struct,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_zeta_jet(
         res: *mut acb_struct,
         s: *mut acb_struct,
@@ -109,36 +144,18 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_hurwitz(
         res: *mut acb_struct,
         s: *mut acb_struct,
         a: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_stieltjes(
         res: *mut acb_struct,
         n: *mut fmpz,
         a: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-#[repr(C)]
-#[derive(Copy, Clone)]
-pub struct acb_dirichlet_hurwitz_precomp_struct {
-    pub s: acb_struct,
-    pub err: mag_struct,
-    pub coeffs: acb_ptr,
-    pub deflate: ::std::os::raw::c_int,
-    pub A: mp_limb_signed_t,
-    pub N: mp_limb_signed_t,
-    pub K: mp_limb_signed_t,
-}
-pub type acb_dirichlet_hurwitz_precomp_t = [acb_dirichlet_hurwitz_precomp_struct; 1usize];
-extern "C" {
     pub fn acb_dirichlet_hurwitz_precomp_init(
         pre: *mut acb_dirichlet_hurwitz_precomp_struct,
         s: *mut acb_struct,
@@ -148,8 +165,6 @@ extern "C" {
         N: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_hurwitz_precomp_init_num(
         pre: *mut acb_dirichlet_hurwitz_precomp_struct,
         s: *mut acb_struct,
@@ -157,11 +172,7 @@ extern "C" {
         num_eval: f64,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_hurwitz_precomp_clear(pre: *mut acb_dirichlet_hurwitz_precomp_struct);
-}
-extern "C" {
     pub fn acb_dirichlet_hurwitz_precomp_bound(
         res: *mut mag_struct,
         s: *mut acb_struct,
@@ -169,8 +180,6 @@ extern "C" {
         K: mp_limb_signed_t,
         N: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_hurwitz_precomp_eval(
         res: *mut acb_struct,
         pre: *mut acb_dirichlet_hurwitz_precomp_struct,
@@ -178,8 +187,6 @@ extern "C" {
         q: mp_limb_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_hurwitz_precomp_choose_param(
         A: *mut mp_limb_t,
         K: *mut mp_limb_t,
@@ -188,8 +195,6 @@ extern "C" {
         num_eval: f64,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _acb_dirichlet_euler_product_real_ui(
         res: *mut arb_struct,
         s: mp_limb_t,
@@ -198,14 +203,8 @@ extern "C" {
         reciprocal: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_eta(res: *mut acb_struct, s: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn acb_dirichlet_xi(res: *mut acb_struct, s: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn acb_dirichlet_pairing(
         res: *mut acb_struct,
         G: *mut dirichlet_group_struct,
@@ -213,8 +212,6 @@ extern "C" {
         n: mp_limb_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_pairing_char(
         res: *mut acb_struct,
         G: *mut dirichlet_group_struct,
@@ -222,39 +219,19 @@ extern "C" {
         b: *mut dirichlet_char_struct,
         prec: mp_limb_signed_t,
     );
-}
-#[repr(C)]
-#[derive(Copy, Clone)]
-pub struct acb_dirichlet_roots_struct {
-    pub order: mp_limb_t,
-    pub reduced_order: mp_limb_t,
-    pub z: acb_t,
-    pub size: mp_limb_signed_t,
-    pub depth: mp_limb_signed_t,
-    pub Z: *mut acb_ptr,
-    pub use_pow: ::std::os::raw::c_int,
-}
-pub type acb_dirichlet_roots_t = [acb_dirichlet_roots_struct; 1usize];
-extern "C" {
     pub fn acb_dirichlet_roots_init(
         t: *mut acb_dirichlet_roots_struct,
         order: mp_limb_t,
         num: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_roots_clear(t: *mut acb_dirichlet_roots_struct);
-}
-extern "C" {
     pub fn acb_dirichlet_root(
         z: *mut acb_struct,
         t: *mut acb_dirichlet_roots_struct,
         n: mp_limb_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_chi(
         res: *mut acb_struct,
         G: *mut dirichlet_group_struct,
@@ -262,8 +239,6 @@ extern "C" {
         n: mp_limb_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_chi_vec(
         v: acb_ptr,
         G: *mut dirichlet_group_struct,
@@ -271,16 +246,12 @@ extern "C" {
         nv: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_arb_quadratic_powers(
         v: arb_ptr,
         nv: mp_limb_signed_t,
         x: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_qseries_arb(
         res: *mut acb_struct,
         a: acb_srcptr,
@@ -288,8 +259,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_qseries_arb_powers_naive(
         res: *mut acb_struct,
         x: *mut arb_struct,
@@ -299,8 +268,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_qseries_arb_powers_smallorder(
         res: *mut acb_struct,
         x: *mut arb_struct,
@@ -310,29 +277,19 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_theta_length_d(q: mp_limb_t, x: f64, prec: mp_limb_signed_t) -> mp_limb_t;
-}
-extern "C" {
     pub fn acb_dirichlet_theta_length(
         q: mp_limb_t,
         x: *mut arb_struct,
         prec: mp_limb_signed_t,
     ) -> mp_limb_t;
-}
-extern "C" {
     pub fn mag_tail_kexpk2_arb(res: *mut mag_struct, a: *mut arb_struct, n: mp_limb_t);
-}
-extern "C" {
     pub fn _acb_dirichlet_theta_argument_at_arb(
         xt: *mut arb_struct,
         q: mp_limb_t,
         t: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_theta_arb(
         res: *mut acb_struct,
         G: *mut dirichlet_group_struct,
@@ -340,8 +297,6 @@ extern "C" {
         t: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_ui_theta_arb(
         res: *mut acb_struct,
         G: *mut dirichlet_group_struct,
@@ -349,64 +304,48 @@ extern "C" {
         t: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_gauss_sum_naive(
         res: *mut acb_struct,
         G: *mut dirichlet_group_struct,
         chi: *mut dirichlet_char_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_gauss_sum_factor(
         res: *mut acb_struct,
         G: *mut dirichlet_group_struct,
         chi: *mut dirichlet_char_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_gauss_sum_order2(
         res: *mut acb_struct,
         G: *mut dirichlet_group_struct,
         chi: *mut dirichlet_char_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_gauss_sum_theta(
         res: *mut acb_struct,
         G: *mut dirichlet_group_struct,
         chi: *mut dirichlet_char_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_gauss_sum(
         res: *mut acb_struct,
         G: *mut dirichlet_group_struct,
         chi: *mut dirichlet_char_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_root_number_theta(
         res: *mut acb_struct,
         G: *mut dirichlet_group_struct,
         chi: *mut dirichlet_char_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_root_number(
         res: *mut acb_struct,
         G: *mut dirichlet_group_struct,
         chi: *mut dirichlet_char_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_si_poly_evaluate(
         res: *mut acb_struct,
         v: *mut mp_limb_signed_t,
@@ -414,8 +353,6 @@ extern "C" {
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_jacobi_sum_naive(
         res: *mut acb_struct,
         G: *mut dirichlet_group_struct,
@@ -423,16 +360,12 @@ extern "C" {
         chi2: *mut dirichlet_char_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn jacobi_one_prime(
         p: mp_limb_t,
         e: mp_limb_t,
         pe: mp_limb_t,
         cond: mp_limb_t,
     ) -> mp_limb_t;
-}
-extern "C" {
     pub fn acb_dirichlet_jacobi_sum_factor(
         res: *mut acb_struct,
         G: *mut dirichlet_group_struct,
@@ -440,8 +373,6 @@ extern "C" {
         chi2: *mut dirichlet_char_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_jacobi_sum_gauss(
         res: *mut acb_struct,
         G: *mut dirichlet_group_struct,
@@ -449,8 +380,6 @@ extern "C" {
         chi2: *mut dirichlet_char_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_jacobi_sum(
         res: *mut acb_struct,
         G: *mut dirichlet_group_struct,
@@ -458,8 +387,6 @@ extern "C" {
         chi2: *mut dirichlet_char_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_jacobi_sum_ui(
         res: *mut acb_struct,
         G: *mut dirichlet_group_struct,
@@ -467,8 +394,6 @@ extern "C" {
         b: mp_limb_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_l_euler_product(
         res: *mut acb_struct,
         s: *mut acb_struct,
@@ -476,8 +401,6 @@ extern "C" {
         chi: *mut dirichlet_char_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_l_hurwitz(
         res: *mut acb_struct,
         s: *mut acb_struct,
@@ -486,8 +409,6 @@ extern "C" {
         chi: *mut dirichlet_char_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_l(
         res: *mut acb_struct,
         s: *mut acb_struct,
@@ -495,8 +416,6 @@ extern "C" {
         chi: *mut dirichlet_char_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_l_vec_hurwitz(
         res: acb_ptr,
         s: *mut acb_struct,
@@ -504,8 +423,6 @@ extern "C" {
         G: *mut dirichlet_group_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_l_jet(
         res: acb_ptr,
         s: *mut acb_struct,
@@ -515,8 +432,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _acb_dirichlet_l_series(
         res: acb_ptr,
         s: acb_srcptr,
@@ -527,8 +442,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_l_series(
         res: *mut acb_poly_struct,
         s: *mut acb_poly_struct,
@@ -538,8 +451,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_hardy_theta(
         res: acb_ptr,
         t: *mut acb_struct,
@@ -548,8 +459,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_hardy_z(
         res: acb_ptr,
         t: *mut acb_struct,
@@ -558,8 +467,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _acb_dirichlet_hardy_theta_series(
         res: acb_ptr,
         s: acb_srcptr,
@@ -569,8 +476,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_hardy_theta_series(
         res: *mut acb_poly_struct,
         s: *mut acb_poly_struct,
@@ -579,8 +484,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _acb_dirichlet_hardy_z_series(
         res: acb_ptr,
         s: acb_srcptr,
@@ -590,8 +493,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_hardy_z_series(
         res: *mut acb_poly_struct,
         s: *mut acb_poly_struct,
@@ -600,8 +501,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_gram_point(
         res: *mut arb_struct,
         n: *mut fmpz,
@@ -609,123 +508,66 @@ extern "C" {
         chi: *mut dirichlet_char_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_turing_method_bound(p: *mut fmpz) -> mp_limb_t;
-}
-extern "C" {
     pub fn _acb_dirichlet_definite_hardy_z(
         res: *mut arb_struct,
         t: *mut arf_struct,
         pprec: *mut mp_limb_signed_t,
     ) -> ::std::os::raw::c_int;
-}
-extern "C" {
     pub fn _acb_dirichlet_isolate_gram_hardy_z_zero(
         a: *mut arf_struct,
         b: *mut arf_struct,
         n: *mut fmpz,
     );
-}
-extern "C" {
     pub fn _acb_dirichlet_isolate_rosser_hardy_z_zero(
         a: *mut arf_struct,
         b: *mut arf_struct,
         n: *mut fmpz,
     );
-}
-extern "C" {
     pub fn _acb_dirichlet_isolate_turing_hardy_z_zero(
         a: *mut arf_struct,
         b: *mut arf_struct,
         n: *mut fmpz,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_isolate_hardy_z_zero(a: *mut arf_struct, b: *mut arf_struct, n: *mut fmpz);
-}
-extern "C" {
     pub fn _acb_dirichlet_refine_hardy_z_zero(
         res: *mut arb_struct,
         a: *mut arf_struct,
         b: *mut arf_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_hardy_z_zeros(
         res: arb_ptr,
         n: *mut fmpz,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_zeta_zeros(
         res: acb_ptr,
         n: *mut fmpz,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_zeta_zeros(
         res: acb_ptr,
         n: *mut fmpz,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     ) -> mp_limb_signed_t;
-}
-extern "C" {
     pub fn _acb_dirichlet_exact_zeta_nzeros(res: *mut fmpz, t: *mut arf_struct);
-}
-extern "C" {
     pub fn acb_dirichlet_zeta_nzeros(
         res: *mut arb_struct,
         t: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_backlund_s(
         res: *mut arb_struct,
         t: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_backlund_s_bound(res: *mut mag_struct, t: *mut arb_struct);
-}
-extern "C" {
     pub fn acb_dirichlet_zeta_nzeros_gram(res: *mut fmpz, n: *mut fmpz);
-}
-extern "C" {
     pub fn acb_dirichlet_backlund_s_gram(n: *mut fmpz) -> mp_limb_signed_t;
-}
-#[repr(C)]
-#[derive(Copy, Clone)]
-pub struct acb_dirichlet_platt_c_precomp_struct {
-    pub len: mp_limb_signed_t,
-    pub p: arb_ptr,
-    pub Xa: arb_struct,
-    pub Xb: arb_struct,
-}
-pub type acb_dirichlet_platt_c_precomp_t = [acb_dirichlet_platt_c_precomp_struct; 1usize];
-#[repr(C)]
-#[derive(Copy, Clone)]
-pub struct acb_dirichlet_platt_i_precomp_struct {
-    pub c1: arb_struct,
-    pub c2: arb_struct,
-}
-pub type acb_dirichlet_platt_i_precomp_t = [acb_dirichlet_platt_i_precomp_struct; 1usize];
-#[repr(C)]
-#[derive(Copy, Clone)]
-pub struct acb_dirichlet_platt_ws_precomp_struct {
-    pub pre_c: acb_dirichlet_platt_c_precomp_struct,
-    pub pre_i: acb_dirichlet_platt_i_precomp_struct,
-}
-pub type acb_dirichlet_platt_ws_precomp_t = [acb_dirichlet_platt_ws_precomp_struct; 1usize];
-extern "C" {
     pub fn acb_dirichlet_platt_c_precomp_init(
         pre: *mut acb_dirichlet_platt_c_precomp_struct,
         sigma: mp_limb_signed_t,
@@ -733,11 +575,7 @@ extern "C" {
         k: mp_limb_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_c_precomp_clear(pre: *mut acb_dirichlet_platt_c_precomp_struct);
-}
-extern "C" {
     pub fn acb_dirichlet_platt_c_bound_precomp(
         res: *mut arb_struct,
         pre: *mut acb_dirichlet_platt_c_precomp_struct,
@@ -747,8 +585,6 @@ extern "C" {
         k: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_c_bound(
         res: *mut arb_struct,
         sigma: mp_limb_signed_t,
@@ -757,8 +593,6 @@ extern "C" {
         k: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_i_precomp_init(
         pre: *mut acb_dirichlet_platt_i_precomp_struct,
         A: mp_limb_signed_t,
@@ -766,11 +600,7 @@ extern "C" {
         sigma: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_i_precomp_clear(pre: *mut acb_dirichlet_platt_i_precomp_struct);
-}
-extern "C" {
     pub fn acb_dirichlet_platt_i_bound_precomp(
         res: *mut arb_struct,
         pre_i: *mut acb_dirichlet_platt_i_precomp_struct,
@@ -781,8 +611,6 @@ extern "C" {
         sigma: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_i_bound(
         res: *mut arb_struct,
         t0: *mut arb_struct,
@@ -791,8 +619,6 @@ extern "C" {
         sigma: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_ws_precomp_init(
         pre: *mut acb_dirichlet_platt_ws_precomp_struct,
         A: mp_limb_signed_t,
@@ -800,11 +626,7 @@ extern "C" {
         sigma: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_ws_precomp_clear(pre: *mut acb_dirichlet_platt_ws_precomp_struct);
-}
-extern "C" {
     pub fn acb_dirichlet_platt_ws_interpolation_precomp(
         res: *mut arb_struct,
         deriv: *mut arf_struct,
@@ -819,8 +641,6 @@ extern "C" {
         sigma: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_ws_interpolation(
         res: *mut arb_struct,
         deriv: *mut arf_struct,
@@ -834,8 +654,6 @@ extern "C" {
         sigma: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_bound_C3(
         res: *mut arb_struct,
         t0: *mut arb_struct,
@@ -844,15 +662,11 @@ extern "C" {
         Ns: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_scaled_lambda(
         res: *mut arb_struct,
         t: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_scaled_lambda_vec(
         res: arb_ptr,
         T: *mut fmpz,
@@ -860,15 +674,11 @@ extern "C" {
         B: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_beta(
         res: *mut arb_struct,
         t: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_lemma_32(
         out: *mut arb_struct,
         h: *mut arb_struct,
@@ -876,8 +686,6 @@ extern "C" {
         x: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_lemma_A5(
         out: *mut arb_struct,
         B: mp_limb_signed_t,
@@ -885,8 +693,6 @@ extern "C" {
         k: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_lemma_A7(
         out: *mut arb_struct,
         sigma: mp_limb_signed_t,
@@ -896,8 +702,6 @@ extern "C" {
         A: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_lemma_A9(
         out: *mut arb_struct,
         sigma: mp_limb_signed_t,
@@ -906,8 +710,6 @@ extern "C" {
         A: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_lemma_A11(
         out: *mut arb_struct,
         t0: *mut arb_struct,
@@ -915,8 +717,6 @@ extern "C" {
         B: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_lemma_B1(
         out: *mut arb_struct,
         sigma: mp_limb_signed_t,
@@ -925,8 +725,6 @@ extern "C" {
         J: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_lemma_B2(
         out: *mut arb_struct,
         K: mp_limb_signed_t,
@@ -934,8 +732,6 @@ extern "C" {
         xi: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_multieval(
         out: arb_ptr,
         T: *mut fmpz,
@@ -947,8 +743,6 @@ extern "C" {
         sigma: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_platt_multieval_threaded(
         out: arb_ptr,
         T: *mut fmpz,
@@ -960,8 +754,6 @@ extern "C" {
         sigma: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _acb_dirichlet_platt_local_hardy_z_zeros(
         res: arb_ptr,
         n: *mut fmpz,
@@ -978,32 +770,24 @@ extern "C" {
         sigma_interp: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     ) -> mp_limb_signed_t;
-}
-extern "C" {
     pub fn acb_dirichlet_platt_local_hardy_z_zeros(
         res: arb_ptr,
         n: *mut fmpz,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     ) -> mp_limb_signed_t;
-}
-extern "C" {
     pub fn acb_dirichlet_platt_hardy_z_zeros(
         res: arb_ptr,
         n: *mut fmpz,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     ) -> mp_limb_signed_t;
-}
-extern "C" {
     pub fn acb_dirichlet_dft_index(
         w: acb_ptr,
         v: acb_srcptr,
         G: *mut dirichlet_group_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_dirichlet_dft(
         w: acb_ptr,
         v: acb_srcptr,
